@@ -1,47 +1,47 @@
 $VAR1 = {
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'uploads' => {
-                         'path' => '/var/www/htdocs/download',
-                         'maxlength' => 21000000,
-                         'chmod' => 438
-                       },
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'scriptAlias' => 'perl',
-          'language' => 'en',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
           'mod' => 'n',
+          'scriptAlias' => 'cgi-bin',
+          'actions' => 'cgi-bin//config/actions.pl',
+          'config' => 'cgi-bin//config/settings.pl',
+          'translate' => 'cgi-bin//config/translate.pl',
           'database' => {
-                          'CurrentUser' => 'root',
-                          'name' => 'LZE',
+                          'CurrentPass' => '',
                           'CurrentDb' => 'LZE',
-                          'host' => 'localhost',
+                          'CurrentUser' => 'root',
                           'user' => 'root',
                           'CurrentHost' => 'localhost',
-                          'CurrentPass' => '',
-                          'password' => ''
+                          'name' => 'LZE',
+                          'password' => '',
+                          'host' => 'localhost'
                         },
           'admin' => {
-                       'email' => 'your@email.org',
-                       'password' => 'testpass'
+                       'password' => 'testpass',
+                       'email' => 'your@email.org'
                      },
-          'cgi' => {
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'title' => 'MySQL::Admin',
-                     'cookiePath' => '/',
-                     'style' => 'mysql',
-                     'serverName' => 'localhost',
-                     'alias' => 'perl',
-                     'bin' => '/var/www/cgi-bin',
-                     'expires' => '+1y'
-                   },
+          'uploads' => {
+                         'maxlength' => 21000000,
+                         'path' => '/var/www/htdocs/download',
+                         'chmod' => 438
+                       },
           'files' => {
                        'owner' => 'lze',
-                       'chmod' => '0755',
-                       'group' => 'lze'
+                       'group' => 'lze',
+                       'chmod' => '0755'
                      },
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'language' => 'en',
+          'session' => 'cgi-bin//config/session.pl',
           'floodtime' => 10,
-          'version' => '0.81'
+          'cgi' => {
+                     'cookiePath' => '/',
+                     'expires' => '+1y',
+                     'alias' => 'cgi-bin',
+                     'title' => 'MySQL::Admin',
+                     'serverName' => 'localhost',
+                     'DocumentRoot' => 'htdocs/',
+                     'style' => 'mysql',
+                     'bin' => 'cgi-bin/'
+                   },
+          'version' => '0.82',
+          'apacheconfig' => 'n'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
