@@ -308,7 +308,7 @@ function submitForm(node,tabId,tabTitle,bHistory,method)
     method   = typeof method   !== 'undefined' ? method   : 'POST';
 
     if(checkForm(node)){
-      var url = "../%ALIAS%/mysql.pl?";
+      var url = "../perl/mysql.pl?";
       var formData = new FormData();
       for(var i =0; i < node.elements.length;i++){
 	if(node.elements[i].type == 'checkbox' || node.elements[i].type == 'radio'){
@@ -351,18 +351,19 @@ function submitForm(node,tabId,tabTitle,bHistory,method)
 }
 var http_request = false;
 var oldpage;
-//requestURI('%ALIAS%/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
+//requestURI('perl/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
 function requestURI(url,id,txt,bHistory,formData,method,bWaid)
 {
       closePopup();
-      if(txt)
-	window.document.title = txt;
+//       if(txt)
+// 	window.document.title = txt;
       bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
       method   = typeof method   !== 'undefined' ? method   : 'GET';
-      bWaid    = typeof bWaid     == 'undefined' ? %MODPERL% : false;
+      bWaid    = typeof bWaid     == 'undefined' ? false : false;
       if(bHistory && method == 'GET')
 	history.pushState(null, '','?'+url);
-      if(bWaid){
+      if( bWaid )
+      {
 	var waid = getText('animationContainer');
 	oldpage = '';
 	oldpage = getText('content');
@@ -393,7 +394,7 @@ function requestURI(url,id,txt,bHistory,formData,method,bWaid)
 	http_request.open('GET', url, true);
 	http_request.send(null);
       }else{
-	http_request.open('POST', "../%ALIAS%/mysql.pl?", true);
+	http_request.open('POST', "../perl/mysql.pl?", true);
 	http_request.setRequestHeader("Content-Type", "multipart/form-data");
 	http_request.send(formData);
       }
@@ -401,83 +402,83 @@ function requestURI(url,id,txt,bHistory,formData,method,bWaid)
 
 function loadXMLDoc(filename)
 {
-	if (window.ActiveXObject){
-		xhttp = new ActiveXObject("Msxml2.XMLHTTP");
-	}else{
-		xhttp = new XMLHttpRequest();
-	}
-	xhttp.open("GET", filename, false);
-	xhttp.overrideMimeType("text/xml");
-	try {
-	  xhttp.responseType = "msxml-document"
-	  
-	} catch(err) {
-	  alert(err);
-	}
-	xhttp.send(null);
-	return xhttp.responseXML;
+    if (window.ActiveXObject){
+	    xhttp = new ActiveXObject("Msxml2.XMLHTTP");
+    }else{
+	    xhttp = new XMLHttpRequest();
+    }
+    xhttp.open("GET", filename, false);
+    xhttp.overrideMimeType("text/xml");
+    try {
+      xhttp.responseType = "msxml-document"
+      
+    } catch(err) {
+      alert(err);
+    }
+    xhttp.send(null);
+    return xhttp.responseXML;
 }
 
 function setContent()
 {
-        if (http_request.readyState == 4) {
-           if (http_request.status == 200) {
-	      response      = http_request.responseXML;
-	      for(var i = 0; i < response.getElementsByTagName('output').length; i++){
-		var outID = response.getElementsByTagName('output')[i].getAttribute('id')
-		var txt  = response.getElementsByTagName('output')[i].textContent;
-		if (navigator.userAgent.indexOf("Firefox")!=-1)
-		    txt = txt.replace("<![CDATA[", "").replace("]]>", "");
-		setText(outID,txt);
-		evalId(outID);
-	      }
-	   }else{
-		setText('content',oldpage);
-		setCurrentTab(currentId, currentTxt);
+    if (http_request.readyState == 4) {
+	if (http_request.status == 200) {
+	  response      = http_request.responseXML;
+	  for(var i = 0; i < response.getElementsByTagName('output').length; i++){
+	    var outID = response.getElementsByTagName('output')[i].getAttribute('id')
+	    var txt  = response.getElementsByTagName('output')[i].textContent;
+	    if (navigator.userAgent.indexOf("Firefox")!=-1)
+		txt = txt.replace("<![CDATA[", "").replace("]]>", "");
+	    setText(outID,txt);
+	    evalId(outID);
 	  }
-	  var closeButton = $("closeButton");
-	  if(!document.cookie.match('sid') || document.cookie.match('sid=123') ){
-	    showPopup('login',true);
-	    evalId('popupContent');
-	  }else{
-	    closeButton.addEventListener ('click',closePopup);
-	  }
-	  hide('toolbarcontent2');
-	  hide('toolbarcontent');
-	  if($('toolbar'))
-	    $('toolbar').classList.add('closed');
-	  if($('toolbar2'))
-	    $('toolbar2').classList.add('closed');
-        }
+	}else{
+	    setText('content',oldpage);
+	    setCurrentTab(currentId, currentTxt);
+      }
+      var closeButton = $("closeButton");
+      if(!document.cookie.match('sid') || document.cookie.match('sid=123') ){
+	showPopup('login',true);
+	evalId('popupContent');
+      }else{
+	closeButton.addEventListener ('click',closePopup);
+      }
+      hide('toolbarcontent2');
+      hide('toolbarcontent');
+      if($('toolbar'))
+	$('toolbar').classList.add('closed');
+      if($('toolbar2'))
+	$('toolbar2').classList.add('closed');
+    }
 }
 
 function evalId(id)
 {
-	var content  = $(id);
-	if(content){
-	  var node = content.getElementsByTagName("script");
-	  for(var i=0,j=node.length; i<j; i++){
-	    if(node[i] && node[i].childNodes[0])
-	      eval(node[i].childNodes[0].nodeValue);
-	  }
-	}
+    var content  = $(id);
+    if(content){
+      var node = content.getElementsByTagName("script");
+      for(var i=0,j=node.length; i<j; i++){
+	if(node[i] && node[i].childNodes[0])
+	  eval(node[i].childNodes[0].nodeValue);
+      }
+    }
 }
 
 window.onpopstate =loadHistory;
 function loadHistory()
 {
-	var rxObj =  new RegExp(/action=([^&]+)/);
-	rxObj.exec(window.location.search);
-	var action = RegExp.$1;
-	var rxObj2 =  new RegExp(/(\?[^\?]+$)/);
-	rxObj2.exec(window.location.search);
-	var uri = RegExp.$1;
-	var url = window.location.search;
-	if(uri && action){
-	   requestURI('%ALIAS%/mysql.pl'+uri,action,action,false);
-	}else
-	  requestURI('%ALIAS%/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
-	return true;
+    var rxObj =  new RegExp(/action=([^&]+)/);
+    rxObj.exec(window.location.search);
+    var action = RegExp.$1;
+    var rxObj2 =  new RegExp(/(\?[^\?]+$)/);
+    rxObj2.exec(window.location.search);
+    var uri = RegExp.$1;
+    var url = window.location.search;
+    if(uri && action){
+	requestURI('perl/mysql.pl'+uri,action,action,false);
+    }else
+      requestURI('perl/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
+    return true;
 }
 
 function translate(string)
