@@ -21,7 +21,7 @@ use vars qw(
 );
 @HTML::Menu::Pages::EXPORT  = qw(makePages);
 @ISA                        = qw(Exporter);
-$HTML::Menu::Pages::VERSION = '0.79';
+$HTML::Menu::Pages::VERSION = '0.82';
 $DefaultClass               = 'HTML::Menu::Pages' unless defined $HTML::Menu::Pages::DefaultClass;
 
 =head1 NAME
@@ -80,7 +80,7 @@ use HTML::Menu::Pages;
 
         print makePages(\%needed );
 
-
+# 
 =head2 Changes
 
 0.37
@@ -123,7 +123,7 @@ sub makePages
     $mod_rewrite = $hashref->{mod_rewrite} ? $hashref->{mod_rewrite} : 0;
     $append      = $hashref->{append} ? $hashref->{append} : '';
     $length      = $hashref->{length} ? $hashref->{length} : 0;
-    $pages       = $hashref->{title} ? $hashref->{title} : "Start: ";
+    $pages       = $hashref->{title} ? $hashref->{title} : '0';
     $path        = $hashref->{path} ? $hashref->{path} : 'cgi-bin/';
     $per_page    = $hashref->{links_pro_page} ? $hashref->{links_pro_page} : 10;
     $bAjax     = $hashref->{ajax} ? $hashref->{ajax} : 0;
